@@ -30,14 +30,14 @@ public:
     }
     // This should be static but cannot bind static functions to QJSEngine
     Q_INVOKABLE QJSValue setTimeout(QJSValue callback, QJSValue delayTime, QJSValue args) {
-        qDebug() << callback.toString() << delayTime.toInt() << args.toString();
+        // qDebug() << callback.toString() << delayTime.toInt() << args.toString();
 
         QJSValueList valueArgs;
         if (args.isArray()) {
             const int argsLength = args.property("length").toInt();
             for (int i = 0; i < argsLength; ++i) {
                 auto arg = args.property(i);
-                qDebug() << "Adding arg" << arg.toString();
+                // qDebug() << "Adding arg" << arg.toString();
                 valueArgs << arg;
             }
         }
@@ -45,12 +45,12 @@ public:
         auto timer = new JSTimer();
         timer->setInterval(delayTime.toInt());
         connect(timer, &JSTimer::timeout, this, [callback, valueArgs]() mutable {
-            qDebug() << "Calling" << callback.toString();
+            // qDebug() << "Calling" << callback.toString();
             if (!callback.isCallable()) qDebug() << callback.toString() << "is not callable";
             auto value = callback.call(valueArgs);
             if (value.isError()) {
                 qWarning() << "Error" << value.toString();
-                qDebug() << value.property("stack").toString().splitRef('\n');
+                qDebug() << value.property("stack").toString().split('\n');
             }
         });
         timer->start();
@@ -79,12 +79,13 @@ public:
     static JS &instance();
 
     explicit JS(QObject *parent = nullptr);
-    JSNAMFactory &getNamFactory() { return namFactory; };
+    JSNAMFactory &getNamFactory() { return namFactory; }
 
     void initialize(const QUrl &url);
     bool checkError(const QJSValue &value);
 
     bool isInitialized();
+    void setEngine(QQmlEngine *value) { engine = value; }
     QQmlEngine &getEngine() { return *engine; }
 
     JSResult &callFunction(JSResult *result, const QString &name, const QJSValueList &args);
