@@ -7,7 +7,7 @@ class JSNAMFactory : public QQmlNetworkAccessManagerFactory {
 public:
     QNetworkAccessManager *create(QObject *parent);
 
-    void setRequestHeaders(QMap<QByteArray, QByteArray> value) { requestHeaders = value; };
+    void setRequestHeaders(QMap<QByteArray, QByteArray> value) { requestHeaders = value; }
     const QMap<QByteArray, QByteArray> &getRequestHeaders() const { return requestHeaders; }
 
 private:
@@ -28,14 +28,4 @@ private:
     const JSNAMFactory &factory;
 };
 
-class JSDiskCache : public QNetworkDiskCache {
-public:
-    JSDiskCache(QObject *parent);
-    void updateMetaData(const QNetworkCacheMetaData &meta);
-    QIODevice *prepare(const QNetworkCacheMetaData &meta);
-
-private:
-    QNetworkCacheMetaData fixMetadata(const QNetworkCacheMetaData &meta);
-};
-
 #endif // YTJSNAMFACTORY_H
