@@ -126,24 +126,28 @@ void MediaMPV::handleMpvEvent(mpv_event *event) {
     case MPV_EVENT_PLAYBACK_RESTART: {
         int pause;
         mpv_get_property(mpv, "pause", MPV_FORMAT_FLAG, &pause);
-        bool paused = pause == 1;
-        if (paused)
+        bool isPaused = pause == 1;
+        if (isPaused) {
             setState(Media::PausedState);
-        else
+            emit paused(true);
+        } else {
             setState(Media::PlayingState);
+            emit started();
+        }
         break;
     }
 
     case MPV_EVENT_FILE_LOADED:
         // Add separate audiofile if there is any
-        if (!audioFileToAdd.isEmpty())
-        {
+        if (!audioFileToAdd.isEmpty()) {
             const QByteArray audioUtf8 = audioFileToAdd.toUtf8();
             const char *args2[] = {"audio-add", audioUtf8.constData(), nullptr};
             sendCommand(args2);
             audioFileToAdd.clear();
         }
         setState(Media::PlayingState);
+        emit loaded();
+        emit started();
         break;
 
     case MPV_EVENT_END_FILE: {
@@ -274,8 +278,8 @@ void MediaMPV::playSeparateAudioAndVideo(const QString &video, const QString &au
     const char *args[] = {"loadfile", fileUtf8.constData(), nullptr};
     sendCommand(args);
 
-    // We are playing audio as separate file. The add audio command must executed when the main file is loaded
-    // Otherwise the audio file doesn't gets played
+    // We are playing audio as separate file. The add audio command must executed when the main file
+    // is loaded Otherwise the audio file doesn't gets played
     audioFileToAdd = audio;
 
     qApp->processEvents();
