@@ -93,6 +93,8 @@ void DefaultUpdater::update() {
         installer->setUpdater(this);
     }
     connect(installer, &Installer::error, this, [](auto message) { qWarning() << message; });
+    connect(installer, &Installer::finished, this,
+            [this]() { setStatus(Updater::Status::UpToDate); });
     installer->start(downloadedFilename);
 }
 
@@ -109,15 +111,16 @@ Downloader *DefaultUpdater::downloadUpdate() {
         downloader->deleteLater();
         downloader = nullptr;
         downloadedFilename = filename;
+        setStatus(Updater::Status::UpdateDownloaded);
 
-        if (getImmediateInstallAndRelaunch()) {
+        if (getImmediateInstallWithoutRelaunch()) {
+            update();
+        } else if (getImmediateInstallAndRelaunch()) {
             update();
             qApp->quit();
         } else {
             connect(qApp, &QCoreApplication::aboutToQuit, this, [this] { update(); });
         }
-
-        setStatus(Updater::Status::UpdateDownloaded);
     });
 
     connect(downloader, &Downloader::error, [this](auto message) {
