@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="id">
 <context>
     <name>AboutView</name>
     <message>
@@ -670,7 +670,7 @@
     </message>
     <message>
         <source>Toggle &amp;Menu Bar</source>
-        <translation type="unfinished"/>
+        <translation>Beralih &amp; Bilah Menu</translation>
     </message>
     <message>
         <source>Menu</source>
@@ -790,7 +790,7 @@
     </message>
     <message>
         <source>You can still access the menu bar by pressing the ALT key</source>
-        <translation type="unfinished"/>
+        <translation>Anda masih dapat mengakses bilah menu dengan menekan tombol ALT</translation>
     </message>
 </context>
 <context>
