@@ -35,13 +35,14 @@ $END_LICENSE */
 #include "fontutils.h"
 #include "iconutils.h"
 #include "mainwindow.h"
+#include "views.h"
 
 #ifdef UPDATER
 #include "updater.h"
 #include "waitingspinnerwidget.h"
 #endif
 
-AboutView::AboutView(QWidget *parent) : View(parent) {
+AboutView::AboutView(QWidget *parent) : QWidget(parent) {
     const int padding = 30;
     const char *buildYear = __DATE__ + 7;
 
@@ -50,13 +51,13 @@ AboutView::AboutView(QWidget *parent) : View(parent) {
     setAutoFillBackground(true);
 
     QBoxLayout *verticalLayout = new QVBoxLayout(this);
-    verticalLayout->setMargin(0);
+    verticalLayout->setContentsMargins(0, 0, 0, 0);
     verticalLayout->setSpacing(0);
 
     QBoxLayout *aboutlayout = new QHBoxLayout();
     verticalLayout->addLayout(aboutlayout, 1);
     aboutlayout->setAlignment(Qt::AlignCenter);
-    aboutlayout->setMargin(padding);
+    aboutlayout->setContentsMargins(padding, padding, padding, padding);
     aboutlayout->setSpacing(padding);
 
     ClickableLabel *logo = new ClickableLabel();
@@ -72,7 +73,7 @@ AboutView::AboutView(QWidget *parent) : View(parent) {
     QBoxLayout *layout = new QVBoxLayout();
     layout->setAlignment(Qt::AlignCenter);
     layout->setSpacing(padding);
-    layout->setMargin(padding / 2);
+    layout->setContentsMargins(padding / 2, padding / 2, padding / 2, padding / 2);
     aboutlayout->addLayout(layout);
 
     QColor lightTextColor = palette().text().color();
@@ -122,7 +123,7 @@ AboutView::AboutView(QWidget *parent) : View(parent) {
     info += "<p>" +
             tr("Translate %1 to your native language using %2")
                     .arg(Constants::NAME)
-                    .arg("<a href='http://www.transifex.net/projects/p/" +
+                    .arg("<a href='https://app.transifex.com/flaviotordini/" +
                          QString(Constants::UNIX_NAME) + "/'>Transifex</a>") +
             "</p>";
 
@@ -130,10 +131,6 @@ AboutView::AboutView(QWidget *parent) : View(parent) {
             tr("Powered by %1")
                     .arg("<a href='https://" + QLatin1String(Constants::ORG_DOMAIN) +
                          "/opensource'>" + tr("Open-source software") + "</a>") +
-            "</p>";
-
-    info += "<p>" +
-            tr("Icon designed by %1.").arg("<a href='http://www.kolorguild.co.za/'>David Nel</a>") +
             "</p>"
 
 #ifndef APP_EXTRA
@@ -156,7 +153,7 @@ AboutView::AboutView(QWidget *parent) : View(parent) {
     int capHeight = fontMetrics().capHeight();
 
     QBoxLayout *updateLayout = new QHBoxLayout();
-    updateLayout->setMargin(0);
+    updateLayout->setContentsMargins(0, 0, 0, 0);
     updateLayout->setSpacing(capHeight);
     updateLayout->setAlignment(Qt::AlignLeft);
 
@@ -181,30 +178,30 @@ AboutView::AboutView(QWidget *parent) : View(parent) {
 #endif
 
     QLayout *buttonLayout = new QHBoxLayout();
-    buttonLayout->setMargin(0);
+    buttonLayout->setContentsMargins(0, 0, 0, 0);
     buttonLayout->setAlignment(Qt::AlignLeft);
 
 #ifdef UPDATER
     buttonLayout->addWidget(Updater::instance().getButton());
 #endif
 
-    closeButton = new QPushButton(tr("&Close"), this);
+    auto closeButton = new QPushButton(tr("&Close"), this);
     closeButton->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
     closeButton->setDefault(true);
     closeButton->setShortcut(Qt::Key_Escape);
     closeButton->setFocus();
-    connect(closeButton, SIGNAL(clicked()), MainWindow::instance(), SLOT(goBack()));
+    connect(closeButton, &QAbstractButton::clicked, MainWindow::instance()->getViews(),
+            &Views::goBack);
     buttonLayout->addWidget(closeButton);
 
     layout->addLayout(buttonLayout);
 
 #ifndef APP_WIN_STORE
-    verticalLayout->addWidget(new AppsWidget());
+    verticalLayout->addWidget(new AppsWidget(this));
 #endif
 }
 
-void AboutView::appear() {
-    closeButton->setFocus();
+void AboutView::showEvent(QShowEvent *event) {
 #ifdef UPDATER
     Updater::instance().checkWithoutUI();
 #endif
