@@ -23,15 +23,17 @@ $END_LICENSE */
 #include "searchparams.h"
 #include "video.h"
 #include "ytchannel.h"
-#include "ytsearch.h"
 #ifdef APP_MAC
 #include "macutils.h"
 #endif
 #include "http.h"
 #include "httputils.h"
 
+#ifdef YT_IV
 #include "ivchannelsource.h"
+#endif
 #include "videoapi.h"
+
 #include "ytjschannelsource.h"
 
 ChannelAggregator::ChannelAggregator(QObject *parent)
@@ -66,7 +68,7 @@ YTChannel *ChannelAggregator::getChannelToCheck() {
     QSqlQuery query(db);
     query.prepare("select user_id from subscriptions where checked<? "
                   "order by checked limit 1");
-    query.bindValue(0, QDateTime::currentDateTimeUtc().toTime_t() - checkInterval);
+    query.bindValue(0, QDateTime::currentSecsSinceEpoch() - checkInterval);
     bool success = query.exec();
     if (!success) qWarning() << query.lastQuery() << query.lastError().text();
     if (query.next()) return YTChannel::forId(query.value(0).toString());
@@ -115,9 +117,11 @@ void ChannelAggregator::checkWebPage(YTChannel *channel) {
 
 void ChannelAggregator::parseWebPage(const QByteArray &bytes) {
     bool hasNewVideos = true;
-    QRegExp re = QRegExp("[\\?&]v=([0-9A-Za-z_-]+)");
-    if (re.indexIn(bytes) != -1) {
-        QString videoId = re.cap(1);
+    static QRegularExpression re("[\\?&]v=([\\w_-]+)",
+                                 QRegularExpression::UseUnicodePropertiesOption);
+    auto match = re.match(bytes);
+    if (match.hasMatch()) {
+        QString videoId = match.captured(1);
         QString latestVideoId = currentChannel->latestVideoId();
         qDebug() << "Comparing" << videoId << latestVideoId;
         hasNewVideos = videoId != latestVideoId;
@@ -149,22 +153,20 @@ void ChannelAggregator::reallyProcessChannel(YTChannel *channel) {
     params->setTransient(true);
     params->setPublishedAfter(channel->getChecked());
 
-    if (VideoAPI::impl() == VideoAPI::YT3) {
-        YTSearch *videoSource = new YTSearch(params);
-        connect(videoSource, SIGNAL(gotVideos(QVector<Video *>)),
-                SLOT(videosLoaded(QVector<Video *>)));
-        videoSource->loadVideos(50, 1);
-    } else if (VideoAPI::impl() == VideoAPI::IV) {
-        auto *videoSource = new IVChannelSource(params);
-        connect(videoSource, SIGNAL(gotVideos(QVector<Video *>)),
-                SLOT(videosLoaded(QVector<Video *>)));
-        videoSource->loadVideos(50, 1);
-    } else if (VideoAPI::impl() == VideoAPI::JS) {
-        auto *videoSource = new YTJSChannelSource(params);
-        connect(videoSource, SIGNAL(gotVideos(QVector<Video *>)),
-                SLOT(videosLoaded(QVector<Video *>)));
-        videoSource->loadVideos(50, 1);
-    }
+#ifdef YT_YT3
+    YTSearch *videoSource = new YTSearch(params);
+    connect(videoSource, SIGNAL(gotVideos(QVector<Video *>)), SLOT(videosLoaded(QVector<Video *>)));
+    videoSource->loadVideos(50, 1);
+#endif
+#ifdef YT_IV
+    auto *videoSource = new IVChannelSource(params);
+    connect(videoSource, SIGNAL(gotVideos(QVector<Video *>)), SLOT(videosLoaded(QVector<Video *>)));
+    videoSource->loadVideos(50, 1);
+#endif
+
+    auto *videoSource = new YTJSChannelSource(params);
+    connect(videoSource, SIGNAL(gotVideos(QVector<Video *>)), SLOT(videosLoaded(QVector<Video *>)));
+    videoSource->loadVideos(50, 1);
 
     channel->updateChecked();
 }
@@ -251,8 +253,8 @@ void ChannelAggregator::addVideo(Video *video) {
 
     if (!updatedChannels.contains(channel)) updatedChannels << channel;
 
-    uint now = QDateTime::currentDateTimeUtc().toTime_t();
-    uint published = video->getPublished().toTime_t();
+    uint now = QDateTime::currentSecsSinceEpoch();
+    uint published = video->getPublished().toSecsSinceEpoch();
     if (published > now) {
         qDebug() << "fixing publish time";
         published = now;
@@ -301,7 +303,7 @@ void ChannelAggregator::addVideo(Video *video) {
 }
 
 void ChannelAggregator::markAllAsWatched() {
-    uint now = QDateTime::currentDateTimeUtc().toTime_t();
+    uint now = QDateTime::currentSecsSinceEpoch();
 
     QSqlDatabase db = Database::instance().getConnection();
     QSqlQuery query(db);
@@ -325,7 +327,7 @@ void ChannelAggregator::videoWatched(Video *video) {
     QSqlDatabase db = Database::instance().getConnection();
     QSqlQuery query(db);
     query.prepare("update subscriptions_videos set watched=? where video_id=?");
-    query.bindValue(0, QDateTime::currentDateTimeUtc().toTime_t());
+    query.bindValue(0, QDateTime::currentSecsSinceEpoch());
     query.bindValue(1, video->getId());
     bool success = query.exec();
     if (!success) qWarning() << query.lastQuery() << query.lastError().text();
