@@ -28,13 +28,14 @@ $END_LICENSE */
 #include "mainwindow.h"
 #include "searchparams.h"
 #include "ytchannel.h"
-#include "ytsearch.h"
 #ifdef APP_EXTRA
 #include "extra.h"
 #endif
 #include "channellistview.h"
 
+#ifdef YT_IV
 #include "ivchannelsource.h"
+#endif
 #include "videoapi.h"
 #include "ytjschannelsource.h"
 
@@ -43,9 +44,10 @@ const QString sortByKey = "subscriptionsSortBy";
 const QString showUpdatedKey = "subscriptionsShowUpdated";
 } // namespace
 
-ChannelView::ChannelView(QWidget *parent) : View(parent), showUpdated(false), sortBy(SortByName) {
+ChannelView::ChannelView(QWidget *parent)
+    : QWidget(parent), showUpdated(false), sortBy(SortByName) {
     QBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
 
     listView = new ChannelListView();
@@ -125,13 +127,13 @@ void ChannelView::setupActions() {
     sortButton->setMenu(sortMenu);
     QWidgetAction *widgetAction = new QWidgetAction(this);
     widgetAction->setDefaultWidget(sortButton);
-    widgetAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_O));
+    widgetAction->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_O));
     statusActions << widgetAction;
 
     markAsWatchedAction = new QAction(tr("Mark all as watched"), this);
     IconUtils::setIcon(markAsWatchedAction, "mark-watched");
     markAsWatchedAction->setEnabled(false);
-    markAsWatchedAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_W));
+    markAsWatchedAction->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_W));
     connect(markAsWatchedAction, SIGNAL(triggered()), SLOT(markAllAsWatched()));
     statusActions << markAsWatchedAction;
 
@@ -140,7 +142,7 @@ void ChannelView::setupActions() {
     IconUtils::setIcon(showUpdatedAction, "show-updated");
     showUpdatedAction->setCheckable(true);
     showUpdatedAction->setChecked(showUpdated);
-    showUpdatedAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_U));
+    showUpdatedAction->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_U));
     connect(showUpdatedAction, SIGNAL(toggled(bool)), SLOT(toggleShowUpdated(bool)));
     statusActions << showUpdatedAction;
 
@@ -155,14 +157,14 @@ QString ChannelView::noSubscriptionsMessage() {
               "Use the star symbol to subscribe to channels.");
 }
 
-void ChannelView::appear() {
+void ChannelView::showEvent(QShowEvent *event) {
     updateQuery(true);
     MainWindow::instance()->showActionsInStatusBar(statusActions, true);
     setFocus();
     ChannelAggregator::instance()->start();
 }
 
-void ChannelView::disappear() {
+void ChannelView::hideEvent(QHideEvent *event) {
     MainWindow::instance()->showActionsInStatusBar(statusActions, false);
 }
 
@@ -175,15 +177,16 @@ void ChannelView::itemActivated(const QModelIndex &index) {
         params->setSortBy(SearchParams::SortByNewest);
         params->setTransient(true);
         VideoSource *vs = nullptr;
-        if (VideoAPI::impl() == VideoAPI::YT3) {
-            YTSearch *videoSource = new YTSearch(params);
-            videoSource->setAsyncDetails(true);
-            vs = videoSource;
-        } else if (VideoAPI::impl() == VideoAPI::IV) {
-            vs = new IVChannelSource(params);
-        } else if (VideoAPI::impl() == VideoAPI::JS) {
-            vs = new YTJSChannelSource(params);
-        }
+#ifdef YT_YT3
+        YTSearch *videoSource = new YTSearch(params);
+        videoSource->setAsyncDetails(true);
+        vs = videoSource;
+#endif
+#ifdef YT_IV
+        vs = new IVChannelSource(params);
+#endif
+        vs = new YTJSChannelSource(params);
+
         emit activated(vs);
         channel->updateWatched();
     } else if (itemType == ChannelModel::ItemAggregate) {
