@@ -21,13 +21,14 @@ $END_LICENSE */
 #include <QtNetwork>
 #include <QtWidgets>
 
+#ifdef QAPPLICATION_CLASS
+#include <singleapplication.h>
+#endif
+
 #include "constants.h"
 #include "iconutils.h"
-#include "updateutils.h"
 
 #include "mainwindow.h"
-#include "searchparams.h"
-#include <qtsingleapplication.h>
 #ifdef APP_EXTRA
 #include "extra.h"
 #endif
@@ -35,34 +36,6 @@ $END_LICENSE */
 #include "mac_startup.h"
 #endif
 
-void showWindow(QtSingleApplication &app, const QString &pkgDataDir) {
-    MainWindow *mainWin = new MainWindow();
-
-#ifndef APP_MAC
-    QIcon appIcon;
-    if (!pkgDataDir.isEmpty()) {
-        appIcon = IconUtils::icon(Constants::UNIX_NAME);
-    } else {
-        QString dataDir = qApp->applicationDirPath() + "/data";
-        const int iconSizes[] = {16, 22, 32, 48, 64, 128, 256, 512};
-        for (int i = 0; i < 8; i++) {
-            QString size = QString::number(iconSizes[i]);
-            QString png = dataDir + '/' + size + 'x' + size + '/' + Constants::UNIX_NAME +
-                          QLatin1String(".png");
-            appIcon.addFile(png, QSize(iconSizes[i], iconSizes[i]));
-        }
-    }
-    if (appIcon.isNull()) appIcon.addFile(":/images/app.png");
-    mainWin->setWindowIcon(appIcon);
-#endif
-
-    mainWin->connect(&app, SIGNAL(messageReceived(const QString &)), mainWin,
-                     SLOT(messageReceived(const QString &)));
-    app.setActivationWindow(mainWin, true);
-
-    mainWin->show();
-}
-
 int main(int argc, char **argv) {
 #ifndef QT_NO_DEBUG_OUTPUT
     qSetMessagePattern("[%{function}] %{message}");
@@ -82,18 +55,22 @@ int main(int argc, char **argv) {
     mac::MacMain();
 #endif
 
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-
-    QtSingleApplication app(argc, argv);
-    QString message;
-    if (app.arguments().size() > 1) {
-        message = app.arguments().at(1);
-        if (message == QLatin1String("--help")) {
-            MainWindow::printHelp();
-            return 0;
+#ifdef QAPPLICATION_CLASS
+    SingleApplication app(argc, argv, true);
+    if (app.isSecondary()) {
+        if (app.arguments().size() > 1) {
+            QString message = app.arguments().at(1);
+            if (message == QLatin1String("--help")) {
+                MainWindow::printHelp();
+            } else {
+                app.sendMessage(message.toUtf8());
+            }
         }
+        return 0;
     }
-    if (app.sendMessage(message)) return 0;
+#else
+    QApplication app(argc, argv);
+#endif
 
     app.setApplicationName(Constants::NAME);
     app.setOrganizationName(Constants::ORG_NAME);
@@ -101,7 +78,6 @@ int main(int argc, char **argv) {
     app.setApplicationVersion(Constants::VERSION);
     app.setAttribute(Qt::AA_DontShowIconsInMenus);
     app.setWheelScrollLines(1);
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps);
 
 #ifdef APP_EXTRA
     Extra::appSetup(&app);
@@ -142,9 +118,40 @@ int main(int argc, char **argv) {
 
     IconUtils::setSizes({16, 24, 32, 88, 128});
 
-    UpdateUtils::init();
+    auto window = new MainWindow();
 
-    showWindow(app, pkgDataDir);
+#ifndef APP_MAC
+    QIcon appIcon;
+    if (!pkgDataDir.isEmpty()) {
+        appIcon = IconUtils::icon(Constants::UNIX_NAME);
+    } else {
+        QString dataDir = qApp->applicationDirPath() + "/data";
+        const int iconSizes[] = {16, 22, 32, 48, 64, 128, 256, 512};
+        for (int i = 0; i < 8; i++) {
+            QString size = QString::number(iconSizes[i]);
+            QString png = dataDir + '/' + size + 'x' + size + '/' + Constants::UNIX_NAME +
+                          QLatin1String(".png");
+            appIcon.addFile(png, QSize(iconSizes[i], iconSizes[i]));
+        }
+    }
+    if (appIcon.isNull()) appIcon.addFile(":/images/app.png");
+    window->setWindowIcon(appIcon);
+#endif
+
+#ifdef QAPPLICATION_CLASS
+    window->connect(&app, &SingleApplication::instanceStarted, window, [window] {
+        window->show();
+        window->raise();
+        window->activateWindow();
+    });
+    window->connect(&app, &SingleApplication::receivedMessage, window,
+                    [window](auto instanceId, auto message) {
+                        Q_UNUSED(instanceId);
+                        window->messageReceived(message);
+                    });
+#endif
+
+    window->show();
 
     return app.exec();
 }
