@@ -25,7 +25,8 @@ $END_LICENSE */
 
 #include "media.h"
 
-class View;
+class ZoomableUI;
+class Views;
 class HomeView;
 class MediaView;
 class DownloadView;
@@ -50,7 +51,7 @@ public:
     void readSettings();
     void writeSettings();
     static void printHelp();
-    QStackedWidget *getViews() { return views; }
+    Views *getViews() { return views; }
     MediaView *getMediaView() { return mediaView; }
     HomeView *getHomeView() { return homeView; }
     QAction *getRegionAction() { return regionAction; }
@@ -83,8 +84,6 @@ public slots:
     void quit();
     void suggestionAccepted(Suggestion *suggestion);
     void search(const QString &query);
-    bool canGoBack() { return history.size() > 1; }
-    void goBack();
     void showMessage(const QString &message);
     void hideMessage();
     void handleError(const QString &message);
@@ -96,7 +95,6 @@ public slots:
 
 signals:
     void currentTimeChanged(const QString &s);
-    void viewChanged();
 
 protected:
     void changeEvent(QEvent *e);
@@ -107,7 +105,6 @@ protected:
     void dropEvent(QDropEvent *e);
     void resizeEvent(QResizeEvent *e);
     void leaveEvent(QEvent *e);
-    void enterEvent(QEvent *e);
 
 private slots:
     void lazyInit();
@@ -155,7 +152,7 @@ private:
     void createMenus();
     void createToolBar();
     void createStatusBar();
-    void showView(View *view, bool transition = false);
+    void showView(QWidget *view);
     static QString formatTime(qint64 duration);
     bool confirmQuit();
     bool needStatusBar();
@@ -164,17 +161,15 @@ private:
     QHash<QByteArray, QAction *> actionMap;
     QHash<QByteArray, QMenu *> menuMap;
 
-    // view mechanism
-    QStackedWidget *views;
-    QStack<View *> history;
+    Views *views;
 
     // view widgets
     HomeView *homeView;
     MediaView *mediaView;
-    View *aboutView;
-    View *downloadView;
-    View *regionsView;
-    View *subscriptionImportView = nullptr;
+    QWidget *aboutView;
+    QWidget *downloadView;
+    QWidget *regionsView;
+    QWidget *subscriptionImportView = nullptr;
 
     // actions
     QAction *backAct;
@@ -197,7 +192,6 @@ private:
     QAction *volumeUpAct;
     QAction *volumeDownAct;
     QAction *volumeMuteAct;
-    QAction *findVideoPartsAct;
 
     // playlist actions
     QAction *removeAct;
@@ -213,7 +207,7 @@ private:
     QMenu *helpMenu;
 
     // toolbar & statusbar
-    QToolBar *mainToolBar;
+    QToolBar *toolbar;
     SearchLineEdit *toolbarSearch;
     QToolBar *statusToolBar;
     QAction *regionAction;
@@ -236,6 +230,7 @@ private:
     QToolButton *toolbarMenuButton;
 
     Media *media;
+    ZoomableUI *zoomableUI;
 };
 
 #endif
