@@ -30,24 +30,31 @@ $END_LICENSE */
 #include "refinesearchwidget.h"
 #include "sidebarheader.h"
 #include "sidebarwidget.h"
-#include "temporary.h"
 #include "videoarea.h"
+
 #ifdef APP_ACTIVATION
 #include "activation.h"
 #include "activationview.h"
 #endif
+
+#ifdef APP_MAC_STORE
+#include "purchasing.h"
+#endif
+
 #ifdef APP_EXTRA
 #include "extra.h"
 #endif
+
 #include "channelaggregator.h"
 #include "iconutils.h"
 #include "searchparams.h"
 #include "videosource.h"
 #include "ytchannel.h"
-#include "ytsearch.h"
+
 #ifdef APP_SNAPSHOT
 #include "snapshotsettings.h"
 #endif
+
 #include "datautils.h"
 #include "idle.h"
 #include "videodefinition.h"
@@ -56,13 +63,15 @@ $END_LICENSE */
 #include "singlevideosource.h"
 #include "videoapi.h"
 
+#include "views.h"
+
 MediaView *MediaView::instance() {
     static MediaView *i = new MediaView();
     return i;
 }
 
 MediaView::MediaView(QWidget *parent)
-    : View(parent), splitter(nullptr), stopped(false)
+    : QWidget(parent), splitter(nullptr), stopped(false)
 #ifdef APP_SNAPSHOT
       ,
       snapshotSettings(nullptr)
@@ -75,7 +84,7 @@ void MediaView::initialize() {
     MainWindow *mainWindow = MainWindow::instance();
 
     QBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     splitter = new MiniSplitter();
     layout->addWidget(splitter);
@@ -133,18 +142,31 @@ void MediaView::initialize() {
     errorTimer->setInterval(3000);
     connect(errorTimer, SIGNAL(timeout()), SLOT(skipVideo()));
 
-#ifdef APP_ACTIVATION
+#if defined APP_ACTIVATION || defined PURCHASING
     demoTimer = new QTimer(this);
     demoTimer->setSingleShot(true);
     connect(
             demoTimer, &QTimer::timeout, this,
             [this] {
                 if (media->state() != Media::PlayingState) return;
-                media->pause();
-                connect(
-                        ActivationView::instance(), &ActivationView::done, media,
-                        [this] { media->play(); }, Qt::UniqueConnection);
+                auto onDismissed = [this] {
+                    media->play();
+                    int ms = (60000 * 2) + (QRandomGenerator::global()->generate() % (60000 * 2));
+                    demoTimer->start(ms);
+                };
+#ifdef APP_ACTIVATION
+                if (Activation::instance().isActivated()) return;
+                connect(ActivationView::instance(), &ActivationView::done, this, onDismissed,
+                        Qt::SingleShotConnection);
                 MainWindow::instance()->showActivationView();
+#elif defined PURCHASING
+                if (Purchasing::instance().isPremium()) return;
+                auto view = Purchasing::instance().getWidget();
+                connect(view, &PurchasingView::done, this, onDismissed, Qt::SingleShotConnection);
+                QMetaObject::invokeMethod(MainWindow::instance()->getAction("buy"),
+                                          &QAction::trigger, Qt::QueuedConnection);
+#endif
+                media->pause();
             },
             Qt::QueuedConnection);
 #endif
@@ -159,9 +181,9 @@ void MediaView::initialize() {
 #ifdef APP_SNAPSHOT
             "snapshot",
 #endif
-            "webpage",  "pagelink", "videolink",     "openInBrowser", "findVideoParts",
-            "skip",     "previous", "stopafterthis", "relatedVideos", "refineSearch",
-            "twitter",  "facebook", "email"};
+            "webpage",      "pagelink", "videolink",     "openInBrowser",
+            "skip",         "previous", "stopafterthis", "relatedVideos",
+            "refineSearch", "x",        "facebook",      "email"};
     currentVideoActions.reserve(videoActionNames.size());
     for (auto *name : videoActionNames) {
         currentVideoActions.append(mainWindow->getAction(name));
@@ -223,13 +245,13 @@ void MediaView::search(SearchParams *searchParams) {
     if (!searchParams->keywords().isEmpty()) {
         if (searchParams->keywords().startsWith("http://") ||
             searchParams->keywords().startsWith("https://")) {
-            QString videoId = YTSearch::videoIdFromUrl(searchParams->keywords());
+            QString videoId = VideoAPI::videoIdFromUrl(searchParams->keywords());
             if (!videoId.isEmpty()) {
                 auto source = new SingleVideoSource(this);
                 source->setVideoId(videoId);
                 setVideoSource(source);
 
-                QTime tstamp = YTSearch::videoTimestampFromUrl(searchParams->keywords());
+                QTime tstamp = VideoAPI::videoTimestampFromUrl(searchParams->keywords());
                 pauseTime = QTime(0, 0).msecsTo(tstamp);
                 return;
             }
@@ -326,18 +348,20 @@ int MediaView::getHistoryIndex() {
     return history.lastIndexOf(playlistModel->getVideoSource());
 }
 
-void MediaView::appear() {
-    MainWindow::instance()->showToolbar();
+void MediaView::showEvent(QShowEvent *event) {
+    auto window = MainWindow::instance();
+
+    if (!window->isCompact()) window->showToolbar();
 
     Video *currentVideo = playlistModel->activeVideo();
     if (currentVideo) {
-        MainWindow::instance()->setWindowTitle(currentVideo->getTitle() + " - " + Constants::NAME);
+        window->setWindowTitle(currentVideo->getTitle() + " - " + Constants::NAME);
     }
 
     playlistView->setFocus();
 }
 
-void MediaView::disappear() {
+void MediaView::hideEvent(QHideEvent *event) {
     MainWindow::instance()->hideToolbar();
 }
 
@@ -400,8 +424,8 @@ void MediaView::pause() {
     }
 }
 
-QRegExp MediaView::wordRE(const QString &s) {
-    return QRegExp("\\W" + s + "\\W?", Qt::CaseInsensitive);
+QRegularExpression MediaView::wordRE(const QString &s) {
+    return QRegularExpression("\\W" + s + "\\W?", QRegularExpression::CaseInsensitiveOption);
 }
 
 void MediaView::stop() {
@@ -422,9 +446,12 @@ void MediaView::stop() {
     errorTimer->stop();
     playlistView->selectionModel()->clearSelection();
 
+    QAction *stopAfterThisAction = MainWindow::instance()->getAction("stopafterthis");
+    if (stopAfterThisAction->isChecked()) stopAfterThisAction->setChecked(false);
+
     MainWindow::instance()->getAction("refineSearch")->setChecked(false);
     updateSubscriptionActionForVideo(nullptr, false);
-#ifdef APP_ACTIVATION
+#if defined APP_ACTIVATION || defined PURCHASING
     demoTimer->stop();
 #endif
 
@@ -490,9 +517,7 @@ void MediaView::activeVideoChanged(Video *video, Video *previousVideo) {
     MainWindow::instance()->getAction("relatedVideos")->setEnabled(true);
 
     bool enableDownload = video->getLicense() == Video::LicenseCC;
-#ifdef APP_ACTIVATION
-    enableDownload = enableDownload || Activation::instance().isLegacy();
-#endif
+
 #ifdef APP_DOWNLOADS
     enableDownload = true;
 #endif
@@ -551,8 +576,8 @@ void MediaView::gotStreamUrl(const QString &streamUrl, const QString &audioUrl)
         playlistView->scrollTo(index, QAbstractItemView::EnsureVisible);
     }
 
-#ifdef APP_ACTIVATION
-    if (!demoTimer->isActive() && !Activation::instance().isActivated()) {
+#if defined APP_ACTIVATION || defined PURCHASING
+    if (!demoTimer->isActive()) {
         int ms = (60000 * 2) + (QRandomGenerator::global()->generate() % (60000 * 2));
         demoTimer->start(ms);
     }
@@ -838,62 +863,6 @@ void MediaView::resumeWithNewStreamUrl(const QString &streamUrl, const QString &
     video->disconnect(this);
 }
 
-void MediaView::findVideoParts() {
-    Video *video = playlistModel->activeVideo();
-    if (!video) return;
-
-    QString query = video->getTitle();
-
-    const QLatin1String optionalSpace("\\s*");
-    const QLatin1String staticCounterSeparators("[\\/\\-]");
-    const QString counterSeparators =
-            QLatin1String("( of | ") + tr("of", "Used in video parts, as in '2 of 3'") +
-            QLatin1String(" |") + staticCounterSeparators + QLatin1String(")");
-
-    // numbers from 1 to 15
-    const QLatin1String counterNumber("([1-9]|1[0-5])");
-
-    // query.remove(QRegExp(counterSeparators + optionalSpace + counterNumber));
-    query.remove(QRegExp(counterNumber + optionalSpace + counterSeparators + optionalSpace +
-                         counterNumber));
-    query.remove(wordRE("pr?t\\.?" + optionalSpace + counterNumber));
-    query.remove(wordRE("ep\\.?" + optionalSpace + counterNumber));
-    query.remove(wordRE("part" + optionalSpace + counterNumber));
-    query.remove(wordRE("episode" + optionalSpace + counterNumber));
-    query.remove(wordRE(tr("part", "This is for video parts, as in 'Cool video - part 1'") +
-                        optionalSpace + counterNumber));
-    query.remove(wordRE(tr("episode", "This is for video parts, as in 'Cool series - episode 1'") +
-                        optionalSpace + counterNumber));
-    query.remove(QRegExp("[\\(\\)\\[\\]]"));
-
-#define NUMBERS "one|two|three|four|five|six|seven|eight|nine|ten"
-
-    QRegExp englishNumberRE = QRegExp(QLatin1String(".*(") + NUMBERS + ").*", Qt::CaseInsensitive);
-    // bool numberAsWords = englishNumberRE.exactMatch(query);
-    query.remove(englishNumberRE);
-
-    QRegExp localizedNumberRE =
-            QRegExp(QLatin1String(".*(") + tr(NUMBERS) + ").*", Qt::CaseInsensitive);
-    // if (!numberAsWords) numberAsWords = localizedNumberRE.exactMatch(query);
-    query.remove(localizedNumberRE);
-
-    SearchParams *searchParams = new SearchParams();
-    searchParams->setTransient(true);
-    searchParams->setKeywords(query);
-    searchParams->setChannelId(video->getChannelId());
-
-    /*
-    if (!numberAsWords) {
-        qDebug() << "We don't have number as words";
-        // searchParams->setSortBy(SearchParams::SortByNewest);
-        // TODO searchParams->setReverseOrder(true);
-        // TODO searchParams->setMax(50);
-    }
-    */
-
-    search(searchParams);
-}
-
 void MediaView::relatedVideos() {
     Video *video = playlistModel->activeVideo();
     if (!video) return;
@@ -905,10 +874,10 @@ void MediaView::relatedVideos() {
     MainWindow::instance()->getAction("relatedVideos")->setEnabled(false);
 }
 
-void MediaView::shareViaTwitter() {
+void MediaView::shareViaX() {
     Video *video = playlistModel->activeVideo();
     if (!video) return;
-    QUrl url("https://twitter.com/intent/tweet");
+    QUrl url("https://x.com/intent/tweet");
     QUrlQuery q;
     q.addQueryItem("via", "minitubeapp");
     q.addQueryItem("text", video->getTitle());
