@@ -137,23 +137,38 @@ void PlaylistItemDelegate::paintBody(QPainter *painter,
     // thumb
     qreal pixelRatio = painter->device()->devicePixelRatioF();
     QByteArray thumbKey = ("t" + QString::number(pixelRatio)).toUtf8();
-    const QPixmap &thumb = video->property(thumbKey).value<QPixmap>();
-    if (!thumb.isNull()) {
-        painter->drawPixmap(0, 0, thumb);
-        if (video->getDuration() > 0) drawTime(painter, video->getFormattedDuration(), line);
-    } else
+    QPixmap thumb = video->property(thumbKey).value<QPixmap>();
+    if (thumb.isNull()) {
+        thumb = IconUtils::icon("content-loading", listView->palette().placeholderText().color())
+                        .pixmap(32);
+        video->setProperty(thumbKey, thumb);
+
         video->loadThumb({thumbWidth, thumbHeight}, pixelRatio)
-                .then([pixelRatio, thumbKey, video](auto variant) {
+                .then([pixelRatio, thumbKey, video, this](auto variant) {
                     QPixmap pixmap;
                     pixmap.loadFromData(variant.toByteArray());
                     pixmap.setDevicePixelRatio(pixelRatio);
                     const int thumbWidth = PlaylistItemDelegate::thumbWidth * pixelRatio;
                     if (pixmap.width() > thumbWidth)
                         pixmap = pixmap.scaledToWidth(thumbWidth, Qt::SmoothTransformation);
+                    if (pixmap.isNull()) {
+                        qDebug() << "Thumb is null";
+                        pixmap = IconUtils::icon("content-loading",
+                                                 listView->palette().placeholderText().color())
+                                         .pixmap(32);
+                    }
                     video->setProperty(thumbKey, pixmap);
                     video->changed();
                 })
                 .onFailed([](auto msg) { qDebug() << msg; });
+    }
+
+    QRect thumbRect(thumb.rect());
+    QRect targetRect(0, 0, thumbWidth, thumbHeight);
+    thumbRect.moveCenter(targetRect.center());
+    painter->drawPixmap(thumbRect.topLeft(), thumb);
+
+    if (video->getDuration() > 0) drawTime(painter, video->getFormattedDuration(), line);
 
     const bool thumbsOnly = line.width() <= thumbWidth + 60;
     const bool isHovered = index.data(HoveredItemRole).toBool();
@@ -171,7 +186,11 @@ void PlaylistItemDelegate::paintBody(QPainter *painter,
             painter->setPen(QPen(option.palette.text(), 0));
 
         // title
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        QStringView title(video->getTitle());
+#else
         QStringRef title(&video->getTitle());
+#endif
         QString elidedTitle = video->getTitle();
         static const int titleFlags = Qt::AlignTop | Qt::TextWordWrap;
         QRect textBox = line.adjusted(padding + thumbWidth, padding, -padding, 0);
@@ -255,7 +274,11 @@ void PlaylistItemDelegate::paintBody(QPainter *painter,
         if (isHovered) {
             painter->setFont(smallerFont);
             painter->setPen(Qt::white);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            QStringView title(video->getTitle());
+#else
             QStringRef title(&video->getTitle());
+#endif
             QString elidedTitle = video->getTitle();
             static const int titleFlags = Qt::AlignTop | Qt::TextWordWrap;
             QRect textBox(padding, padding, thumbWidth - padding * 2, thumbHeight - padding * 2);
