@@ -54,7 +54,7 @@ const QString recentKeywordsKey = "recentKeywords";
 const QString recentChannelsKey = "recentChannels";
 } // namespace
 
-SearchView::SearchView(QWidget *parent) : View(parent) {
+SearchView::SearchView(QWidget *parent) : QWidget(parent) {
     setBackgroundRole(QPalette::Base);
     setForegroundRole(QPalette::Text);
     setAutoFillBackground(true);
@@ -62,7 +62,7 @@ SearchView::SearchView(QWidget *parent) : View(parent) {
     const int padding = 30;
 
     QBoxLayout *vLayout = new QVBoxLayout(this);
-    vLayout->setMargin(padding);
+    vLayout->setContentsMargins(padding, padding, padding, padding);
     vLayout->setSpacing(0);
 
     messageBar = new MessageBar();
@@ -137,10 +137,17 @@ SearchView::SearchView(QWidget *parent) : View(parent) {
     setFocusProxy(slem);
 #else
     SearchLineEdit *sle = new SearchLineEdit(this);
+    sle->setPlaceholderText(tip);
     sle->setFont(FontUtils::medium());
-    int tipWidth = sle->fontMetrics().size(Qt::TextSingleLine, tip).width();
-    sle->setMinimumWidth(tipWidth + sle->fontMetrics().width('m') * 6);
     sle->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
+    auto resizeSle = [sle] {
+        int tipWidth = sle->fontMetrics().size(Qt::TextSingleLine, sle->placeholderText()).width();
+        sle->setMinimumWidth(tipWidth + sle->fontMetrics().xHeight() * 10);
+    };
+    connect(sle, &SearchLineEdit::fontChanged, this, resizeSle);
+    resizeSle();
+    setFocusProxy(sle);
+
     queryEdit = sle;
 #endif
 
@@ -151,7 +158,6 @@ SearchView::SearchView(QWidget *parent) : View(parent) {
             SLOT(textChanged(const QString &)));
     connect(queryEdit->toWidget(), SIGNAL(suggestionAccepted(Suggestion *)),
             SLOT(suggestionAccepted(Suggestion *)));
-    queryEdit->setPlaceholderText(tip);
 
     youtubeSuggest = new YTSuggester(this);
     channelSuggest = new ChannelSuggest(this);
@@ -166,29 +172,19 @@ SearchView::SearchView(QWidget *parent) : View(parent) {
     layout->addSpacing(padding);
 
     QHBoxLayout *recentLayout = new QHBoxLayout();
-    recentLayout->setMargin(0);
+    recentLayout->setContentsMargins(0, 0, 0, 0);
     recentLayout->setSpacing(10);
 
     recentKeywordsLayout = new QVBoxLayout();
-    recentKeywordsLayout->setMargin(0);
+    recentKeywordsLayout->setContentsMargins(0, 0, 0, 0);
     recentKeywordsLayout->setSpacing(0);
     recentKeywordsLayout->setAlignment(Qt::AlignTop | Qt::AlignLeft);
-    recentKeywordsLabel = new QLabel(tr("Recent keywords"));
-    recentKeywordsLabel->setProperty("recentHeader", true);
-    recentKeywordsLabel->hide();
-    recentKeywordsLabel->setEnabled(false);
-    recentKeywordsLayout->addWidget(recentKeywordsLabel);
     recentLayout->addLayout(recentKeywordsLayout);
 
     recentChannelsLayout = new QVBoxLayout();
-    recentChannelsLayout->setMargin(0);
+    recentChannelsLayout->setContentsMargins(0, 0, 0, 0);
     recentChannelsLayout->setSpacing(0);
     recentChannelsLayout->setAlignment(Qt::AlignTop | Qt::AlignLeft);
-    recentChannelsLabel = new QLabel(tr("Recent channels"));
-    recentChannelsLabel->setProperty("recentHeader", true);
-    recentChannelsLabel->hide();
-    recentChannelsLabel->setEnabled(false);
-    recentChannelsLayout->addWidget(recentChannelsLabel);
     recentLayout->addLayout(recentChannelsLayout);
 
     layout->addLayout(recentLayout);
@@ -204,7 +200,7 @@ SearchView::SearchView(QWidget *parent) : View(parent) {
 #endif
 }
 
-void SearchView::appear() {
+void SearchView::showEvent(QShowEvent *event) {
     MainWindow *w = MainWindow::instance();
     w->showActionsInStatusBar(
             {w->getAction("manualplay"), w->getAction("safeSearch"), w->getAction("definition")},
@@ -218,7 +214,7 @@ void SearchView::appear() {
     QTimer::singleShot(0, queryEdit->toWidget(), SLOT(setFocus()));
 }
 
-void SearchView::disappear() {
+void SearchView::hideEvent(QHideEvent *event) {
     MainWindow *w = MainWindow::instance();
     w->showActionsInStatusBar(
             {w->getAction("manualplay"), w->getAction("safeSearch"), w->getAction("definition")},
@@ -235,12 +231,12 @@ void SearchView::updateRecentKeywords() {
     // cleanup
     QLayoutItem *item;
     while (recentKeywordsLayout->count() - 1 > recentKeywords.size() &&
-           (item = recentKeywordsLayout->takeAt(1)) != nullptr) {
+           (item = recentKeywordsLayout->takeAt(0)) != nullptr) {
         item->widget()->close();
         delete item;
     }
 
-    recentKeywordsLabel->setVisible(!keywords.isEmpty());
+    // recentKeywordsLabel->setVisible(!keywords.isEmpty());
     MainWindow::instance()->getAction("clearRecentKeywords")->setEnabled(!keywords.isEmpty());
 
     const int maxDisplayLength = 25;
@@ -327,12 +323,12 @@ void SearchView::updateRecentChannels() {
 
     // cleanup
     QLayoutItem *item;
-    while ((item = recentChannelsLayout->takeAt(1)) != nullptr) {
+    while ((item = recentChannelsLayout->takeAt(0)) != nullptr) {
         item->widget()->close();
         delete item;
     }
 
-    recentChannelsLabel->setVisible(!keywords.isEmpty());
+    // recentChannelsLabel->setVisible(!keywords.isEmpty());
 
 #ifdef APP_MAC
     QPalette p = palette();
@@ -467,11 +463,12 @@ void SearchView::maybeShowMessage() {
 #if defined APP_MAC && !defined APP_MAC_STORE
     if (showMessages && !settings.contains(key = "sofa")) {
         QString msg = tr("Need a remote control for %1? Try %2!").arg(Constants::NAME).arg("Sofa");
-        msg = "<a href='https://" + QLatin1String(Constants::ORG_DOMAIN) + '/' + key +
-              "' style='text-decoration:none;color:palette(windowText)'>" + msg + "</a>";
         messageBar->setMessage(msg);
-        messageBar->setOpenExternalLinks(true);
         disconnect(messageBar);
+        connect(messageBar, &MessageBar::clicked, this, [key] {
+            QString url = "https://" + QLatin1String(Constants::ORG_DOMAIN) + '/' + key;
+            QDesktopServices::openUrl(url);
+        });
         connect(messageBar, &MessageBar::closed, this, [key] {
             QSettings settings;
             settings.setValue(key, true);
@@ -495,11 +492,12 @@ void SearchView::maybeShowMessage() {
                 QString msg =
                         tr("I keep improving %1 to make it the best I can. Support this work!")
                                 .arg(Constants::NAME);
-                msg = "<a href='https://" + QLatin1String(Constants::ORG_DOMAIN) + "/donate" +
-                      "' style='text-decoration:none;color:palette(windowText)'>" + msg + "</a>";
                 messageBar->setMessage(msg);
-                messageBar->setOpenExternalLinks(true);
                 disconnect(messageBar);
+                connect(messageBar, &MessageBar::clicked, this, [] {
+                    QString url = "https://" + QLatin1String(Constants::ORG_DOMAIN) + "/donate";
+                    QDesktopServices::openUrl(url);
+                });
                 connect(messageBar, &MessageBar::closed, this, [key] {
                     QSettings settings;
                     settings.setValue(key, true);
@@ -513,15 +511,9 @@ void SearchView::maybeShowMessage() {
     connect(&Updater::instance(), &Updater::statusChanged, this, [this](auto status) {
         if (status == Updater::Status::UpdateDownloaded) {
             QString msg = tr("An update is ready to be installed. Quit and install update.");
-            msg = "<a href='http://quit' style='text-decoration:none;color:palette(windowText)'>" +
-                  msg + "</a>";
             messageBar->setMessage(msg);
-            messageBar->setOpenExternalLinks(false);
             disconnect(messageBar);
-            connect(messageBar, &MessageBar::linkActivated, this, [] {
-                Updater::instance().setRelaunchAfterInstall(true);
-                qApp->quit();
-            });
+            connect(messageBar, &MessageBar::clicked, this, [] { qApp->quit(); });
             messageBar->show();
         }
     });
