@@ -23,14 +23,12 @@ $END_LICENSE */
 
 #include <QtWidgets>
 
-#include "view.h"
+#include "videosourcewidget.h"
 
 class VideoSource;
-struct YTCategory;
 class YTStandardFeed;
-class VideoSourceWidget;
 
-class StandardFeedsView : public View {
+class StandardFeedsView : public QWidget {
     Q_OBJECT
 
 public:
@@ -40,15 +38,14 @@ signals:
     void activated(VideoSource *standardFeed);
 
 public slots:
-    void appear();
-    void disappear();
     void load();
 
 protected:
+    void showEvent(QShowEvent *event);
+    void hideEvent(QHideEvent *event);
     void paintEvent(QPaintEvent *event);
 
 private slots:
-    void layoutCategories(const QVector<YTCategory> &categories);
     void selectWorldwideRegion();
     void selectLocalRegion();
     void removeVideoSourceWidget(VideoSourceWidget *videoSourceWidget);
@@ -58,8 +55,6 @@ private:
     void addVideoSourceWidget(VideoSource *videoSource);
     void loadNextPreview(VideoSourceWidget *previous = nullptr);
 
-    YTStandardFeed *
-    buildStandardFeed(const QString &feedId, const QString &label, QString time = QString());
     QGridLayout *layout;
     QVector<VideoSourceWidget *> sourceWidgets;
 };
